@@ -40,7 +40,7 @@ public:
     /**
      * Destructor
      */
-    ~KLinkDialog();
+    ~KLinkDialog() override;
 
     /**
      * Returns the link text shown in the dialog
